We deeply appreciate any effort to discover and disclose security vulnerabilities responsibly.

If you would like to report a vulnerability in one of our products, or have security concerns regarding Coralogix software, please email security@coralogix.com.

In order for us to best respond to your report, please include any of the following:

1. Steps to reproduce or proof-of-concept
2. Any relevant tools, including versions used
3. Tool output